@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -68,6 +68,12 @@ impl From<diesel::r2d2::PoolError> for RegistryError {
     }
 }
 
+impl From<InternalError> for RegistryError {
+    fn from(err: InternalError) -> Self {
+        Self::InternalError(err)
+    }
+}
+
 /// Represents the reason that a node was found to be invalid
 #[derive(Debug)]
 pub enum InvalidNodeError {
